[![pipeline status](https://gitlab.com/nicolalandro/streamlit-pannellum/badges/main/pipeline.svg)](https://gitlab.com/nicolalandro/streamlit-pannellum/-/commits/main) 

[![License: MIT](https://img.shields.io/badge/license-MIT-lightgray)](LICENSE) 
[![pypi package](https://img.shields.io/badge/pypi-streamlit_pannellum-blue)](https://pypi.org/project/streamlit_pannellum/)
[![pypi downloads numbers](https://img.shields.io/pypi/dm/streamlit_pannellum.svg)](https://pypistats.org/packages/streamlit_pannellum)

# Streamlit Pannellum
This plugin is the Streamlit implementation of Pannellum a lightweight, free, and open source panorama viewer for the web.

![app screen view](imgs/app.png)

## Example of usage
Install streamlit_pannellum with pypi:

```
pip install streamlit_pannellum
```

Install streamlit_pannellum with gitlab:

```
pip install streamlit-pannellum --index-url https://gitlab.com/api/v4/projects/51659770/packages/pypi/simple
```

Into your streamlit app (egg. main.py):

```
from streamlit_pannellum import streamlit_pannellum

streamlit_pannellum(
    config={
      "default": {
        "firstScene": "first",
      },
      "scenes": {
        "first": {
          "title": "My first example",
          "type": "equirectangular",
          "panorama": "https://pannellum.org/images/alma.jpg",
          "autoLoad": True,
          "author": "Me",
          "hotSpots": [
            {
              "pitch": 15,
              "yaw": 0,
              "type": "info",
              "text": "This is an info."
            },
            {
              "pitch": 0,
              "yaw": -10,
              "type": "scene",
              "text": "Second scene",
              "sceneId": "second"
            }
          ],
        },
        "second": {
          "title": "My second example",
          "type": "equirectangular",
          "panorama": "https://pannellum.org/images/alma.jpg",
          "autoLoad": True,
          "author": "always Me",
          "hotSpots": [
            {
              "pitch": 15,
              "yaw": 0,
              "type": "info",
              "text": "This is an info."
            },
            {
              "pitch": 0,
              "yaw": -10,
              "type": "scene",
              "text": "First scene",
              "sceneId": "first"
            }
          ],
        }
      }
    }
)
```

## Roadmap
* [ ] Specify the height of pannellum (now fixed to 400px, because 100% it have error)

## Develop
This is the guide for developers.

### Frontend
```
cd streamlit_pannellum/frontend
npm install

npm run dev
# http://localhost:5173/
```

### Streamlit
```
python3 -m venv venv
source venv/bin/activate.fish
pip install streamlit

streamlit run streamlit_pannellum/__init__.py
# http://localhost:8501/
```

## Tesing builded lib
```
python3 -m venv venv
# Set from streamlit_pannellum/__init__.py _RELEASE=True
pip install -e .
streamlit run test.py
```

## Deploy pipy
```
keyring set https://upload.pypi.org/legacy/ <pypi uname>
```

* prepare your ~/.pypirc file

```
[pypi]
repository=https://upload.pypi.org/legacy/
username = __token__
password = <token>
```

* build frontend

```
cd streamlit_pannellum/frontend
rm -rf dist
npm run build
```

* build backend

```
pip install twine

# Set from streamlit_pannellum/__init__.py _RELEASE=True
rm -rf dist

python setup.py sdist
twine check dist/*
```

* upload

```
twine upload dist/*
```


## References
* [python](https://www.python.org/): programming language for develop the tool
* [HTML](https://www.w3schools.com/html/): markup language for the output file generated by the tool
* [JavaScript](https://www.w3schools.com/js/): programming language used into the HTML for logic implementation 
* [vite](https://vitejs.dev/): js builder
* [streamlit](https://streamlit.io/): python library to make quick and dirty UI
* [vite vanilla js streamlit component](https://dev.to/aisone/streamlit-custom-components-vite-vanilla-js-40hl): how to create vanilla js plugin for streamlit
* [How to write setup.py and deploy on pypi](https://medium.com/@joel.barmettler/how-to-upload-your-python-package-to-pypi-65edc5fe9c56): important for deploy the code as python lib
* [Gitlab CI/CD for python registry](https://docs.gitlab.com/ee/user/packages/pypi_repository/): how to setup pipeline to gitlab python registry
* [Pannellum](https://pannellum.org/): a js plugin to show 360/HDRI images and make it explorable.


